# Part of Odoo. See LICENSE file for full copyright and licensing details.

{
    'name': 'test-inherits-depends',
    'version': '0.1',
    'category': 'Hidden/Tests',
    'description': """A module to verify the inheritance using _inherits in non-original modules.""",
    'depends': ['test_inherits'],
    'installable': True,
    'license': 'LGPL-3',
}
